/* 
===========================================================================================
= Replication file for Alexander Herzog and Joshua A. Tucker, "The Dynamics of Dissent:   =
= The Winners-Losers Gap in Attitudes Towards EU Membership in Post-Communist Countries," =
= European Political Science Review, 2010, forthcoming.                                   =
===========================================================================================

NOTE: This file replicates Figures 1, 2, and 3 in the paper, and Figures A-1, A-2, A-3, 
and A-4 in the Appendix to the paper. 

DATE: March 20, 2010

DATA SOURCE: The data set was built from three sources:
 1) the Central and Eastern Eurobarometer (CEEB) individual-level surveys from 1991, 1992, 1995 and 1996,
 2) the Candidate Countries Eurobarometer (CCEB) individual-level surveys from 2001, 2002 and 2003,
 3) macro-economic country-level data collected and kindly shared with us by Grigor Pop-Eleches.
 
See the paper for more details about the data and coding decisions.
*/

clear                                                               
version 10.0                                                        
set more off
capture log close
set mem 128m
set scheme s1mono
#delimit;

* =============================
* = FILE PATHS AND GRAPH TYPE =
* =============================;
global DATA = "~/replication_files/data/";
global GRAPHS = "~/replication_files/figures/";
global GRAPH_TYPE = "eps";

* Load dataset;
use "${DATA}country_level_data.dta";

/* FIGURE 1 
Proportion of EU supporters in each country-year survey against the European Bank for Recovery and Development (EBRD)'s Transition Indicator. Lines are linear regression lines. The figures show that less economically successful countries had higher levels of aggregate support for EU membership. Countries included are Bulgaria (BG), Czech Republic (CZ), Estonia (EE), Hungary (HU), Latvia (LT), Lithuania (LV), Poland (PL), Romania (RO), Slovakia (SI), Slovenia (SK).
*/
scatter eu_for transition_indicator9, mlabel(country_short) mlabpos(0) s(i)
 	|| lfit eu_for transition_indicator9,
	by(year,
		rescale
	 	ixaxes
		iscale(*.8)
		note("")
		legend(off)
		)
		ytitle("Proportion of EU supporters")
		xtitle("EBRD Transition Indicator")
		ylabel(0(.2)1);
graph export "${GRAPHS}fig1-eu_support_and_transition_indicator.${GRAPH_TYPE}", replace;


/* FIGURE 2
Proportions of respondents who favor EC membership of their country (1991 and 1992) or would vote for EU membership (1995-2003) of their country if a referendum were held tomorrow. Two surveys are available for 2003, one conducted in May and one in October/November 2003. In the latter, the survey question refers to actual vote decision. Data on EC membership opinion is not available for Slovenia in 1991 because the survey question was not included. Data on EU membership opinion is available for Bulgaria and Romania in 2003 because no referenda were held. Countries are ordered by average support for EU membership in each country. Sample size in each year is about 1,000 respondents.
*/

* relabel year variable;
label def year_short 1 "1991" 2 "1992" 3 "1995" 4 "1996" 5 "1997" 6 "2001" 7 "2002" 8 "2003" 9 "2003";
label val year year_short;

* Overall mean level of EU support;
sum eu_for;
local mean_support = r(mean);

graph bar eu_for, over(year, label(angle(45))) 
	by(country_rank,
	 	ixaxes
		note("")
		)
		ytitle("")
		ylabel(0(.2)1)
		;

graph export "${GRAPHS}fig2-aggregate_eu_membership_support.${GRAPH_TYPE}", replace;


/* FIGURE 3
Proportions of winners and losers supporting EU membership of their countries. Each label represents one particular
country-year observation. The shorter line represents fitted values from an OLS regression of the y-axis variable on the x-axis variable. All observations lie above the 45 degree line which means that in each country and in each year the proportions of winners supporting the EU is greater than the proportions of losers. Countries included are Bulgaria (BG), Czech Republic (CZ), Estonia (EE), Hungary (HU), Latvia (LT), Lithuania (LV), Poland (PL), Romania (RO), Slovakia (SI), Slovenia (SK).
*/
scatter support_winner_perc support_loser_perc, mlabel(country_short) mlabpos(0) s(i)
	|| lfit support_winner_perc support_loser_perc 
	|| function y = x,
	legend(off)
	xtitle("Losers")
	ytitle("Winners");
graph export "${GRAPHS}fig3-proportions_winners_vs_losers.${GRAPH_TYPE}", replace; 		


/* FIGURE A-1
Proportion of EU supporters in each country-year survey against inflation. Hyperinflation countries Bulgaria and Romania are omitted. Lines are linear regression lines. Countries included are Czech Republic (CZ), Estonia (EE), Hungary (HU), Latvia (LT), Lithuania (LV), Poland (PL), Slovakia (SI), Slovenia (SK).
*/
scatter eu_for inflation if country !=1 & country !=8, mlabel(country_short) mlabpos(0) s(i)|| lfit eu_for inflation if country !=1 & country !=8,
	by(year,
		rescale
	 	ixaxes
		iscale(*.8)
		note("")
		legend(off)
		)
		ytitle("Proportion of EU supporters")
		xtitle("Inflation")
		ylabel(0(.2)1);
graph export "${GRAPHS}figA1-eu_support_and_inflation.${GRAPH_TYPE}", replace;


/* FIGURE A-2
Proportion of EU supporters in each country-year survey against change in GDP (\%). Lines are linear regression lines. Countries included are Bulgaria (BG), Czech Republic (CZ), Estonia (EE), Hungary (HU), Latvia (LT), Lithuania (LV), Poland (PL), Romania (RO), Slovakia (SI), Slovenia (SK).
*/
scatter eu_for gdp_change, mlabel(country_short) mlabpos(0) s(i)
 	|| lfit eu_for gdp_change,
	by(year,
		rescale
	 	ixaxes
		iscale(*.8)
		note("")
		legend(off)
		)
		ytitle("Proportion of EU supporters")
		xtitle("GDP Change")
		ylabel(0(.2)1);
graph export "${GRAPHS}figA2-eu_support_and_gdp_change.${GRAPH_TYPE}", replace;


/* FIGURE A-3
Proportion of EU supporters in each country-year survey against unemployment rate. Lines are linear regression lines. Countries included are Bulgaria (BG), Czech Republic (CZ), Estonia (EE), Hungary (HU), Latvia (LT), Lithuania (LV), Poland (PL), Romania (RO), Slovakia (SI), Slovenia (SK).
*/
scatter eu_for unemployment_rate, mlabel(country_short) mlabpos(0) s(i)
 	|| lfit eu_for unemployment_rate,
	by(year,
		rescale
	 	ixaxes
		iscale(*.8)
		note("")
		legend(off)
		)
		ytitle("Proportion of EU supporters")
		xtitle("Unemployment rate")
		ylabel(0(.2)1);
graph export "${GRAPHS}figA3-eu_support_and_unemployment_rate.${GRAPH_TYPE}", replace;


/* FIGURE A-4
Proportion of EU supporters in each country-year survey against GDP relative to 1989. Lines are linear regression lines. Note that in this figure more economically advanced countries have higher levels of support. Countries included are Bulgaria (BG), Czech Republic (CZ), Estonia (EE), Hungary (HU), Latvia (LT), Lithuania (LV), Poland (PL), Romania (RO), Slovakia (SI), Slovenia (SK).
*/
scatter eu_for gdp89, mlabel(country_short) mlabpos(0) s(i)
 	|| lfit eu_for gdp89,
	by(year,
		rescale
	 	ixaxes
		iscale(*.8)
		note("")
		legend(off)
		)
		ytitle("Proportion of EU supporters")
		xtitle("GDP as percentage of GDP in 1989")
		ylabel(0(.2)1);
graph export "${GRAPHS}figA4-eu_support_and_gdp89.${GRAPH_TYPE}", replace;


exit;


