/* 
===========================================================================================
= Replication file for Alexander Herzog and Joshua A. Tucker, "The Dynamics of Dissent:   =
= The Winners-Losers Gap in Attitudes Towards EU Membership in Post-Communist Countries," =
= European Political Science Review, 2010, forthcoming.                                   =
===========================================================================================

NOTES: 
- This file replicates the multilevel models in Table 2 and Figure 6 in the paper. First 
level in all models are individuals and second level are surveys (that is, one particular 
country-year observation). 

- Note that these models are computationally intensive and take considerable time to converge.

- There was a coding error in the 'likely' variable in the original analysis (Slovenia instead 
of Slovakia was coded likely=0 in 1995 and 1996). The below syntax uses the correct coding, but 
the original syntax is provided as well for replication purposes.

DATE: March 20, 2010

DATA SOURCE: The data set was built from three sources:
 1) the Central and Eastern Eurobarometer (CEEB) individual-level surveys from 1991, 1992, 1995 and 1996,
 2) the Candidate Countries Eurobarometer (CCEB) individual-level surveys from 2001, 2002 and 2003,
 3) macro-economic country-level data collected and kindly shared with us by Grigor Pop-Eleches.
 
See the paper for more details about the data and coding decisions.
*/

clear                                                               
version 10.0                                                        
set more off
capture log close
set mem 128m
set scheme s1mono
#delimit;


* =============================
* = FILE PATHS AND GRAPH TYPE =
* =============================;
global DATA = "~/replication_files/data/";
global GRAPHS = "~/replication_files/figures/";
global TABLES = "~/replication_files/tables/";
global GRAPH_TYPE = "eps";


* Load dataset;
use "${DATA}individual_level_data.dta";

* ==================
* = DATA REDUCTION =
* ==================;
* NOTE: See the discussion in the paper for why we reduce the sample.

* Reduce to EU support "for" and EU support "against" groups;
keep if eu_support == 1 | eu_support == 2;

recode eu_support 2=0;
label def eu_support_reduced 0 "against" 1 "for";
label val eu_support eu_support_reduced;


* drop missing values;
drop if eu_support == .;
drop if fpro1 == .;
drop if fpro2 == .;
drop if male == .;
drop if edu2 == .;
drop if edu3 == .;
drop if age == .;


* ================
* = ID VARIABLES =
* ================;
* Survey ID variable;
bysort country year: gen survey_id_tmp = _n; 
replace survey_id_tmp = . if survey_id_tmp != 1;
sort survey_id_tmp country year;
gen survey_id_tmp2 = _n;
replace survey_id_tmp2 = . if survey_id_tmp == .;
bysort country year: egen survey_id = max(survey_id_tmp2);
drop survey_id_tmp*;

* Country ID;
bysort country: gen within_country_id = _n;

* Year ID;
bysort year: gen within_year_id = _n;


* =====================
* = "Likely" variable =
* =====================;
* This variable is 0 (unlikley) for every country in 1991 and 1992, and for Bulgaria, Romania, and Slovakia in 1995 and 1996. This dummy variable seperates countries which were likely to join the EU from those which were rather unlikley to join.;
gen likely = 1;
replace likely = 0 if year == 1991 | year == 1992;

* original but incorrect coding (included here for replication purposes);
* replace likely = 0 if (country == 1 & (year == 1995 | year == 1996)) | (country == 8 & (year == 1995 | year == 1996)) | (country == 10 & (year == 1995 | year == 1996));

* corrected coding;
replace likely = 0 if (country == 1 & (year == 1995 | year == 1996)) | (country == 8 & (year == 1995 | year == 1996)) | (country == 9 & (year == 1995 | year == 1996));


* ====================================
* = "Economically advanced" variable =
* ====================================;
* This dummy varibale distinguishes economically advanced countries from the less economically advanced ones. Here we had several ideas how to code this variable, e.g. all 8 countries about to get in, some subset that are “highest” on transition indicators, some subset with lowest corporate taxation rate.;

* The countries which in 2003 had values above the average valuen on the EBRD transition indicator
* (Czech Republic, Estonia, Hungary, Poland);
* EMA = economically most advanced;
gen ema = (country == 2 | country == 3 | country == 4 | country == 7) & year == 2003;

* =======================
* = Interaction effects =
* =======================;
gen fpro1Xlikely = fpro1*likely;
gen fpro2Xlikely = fpro2*likely;

gen fpro1Xema = fpro1*ema;
gen fpro2Xema = fpro2*ema;


/* TABLE 2 - MODEL 1
Baseline model with varying intercepts only.
*/
log using "${TABLES}tab2-multilevel_model1.log", replace;
xtmelogit eu_support fpro1 fpro2 male edu2 edu3 age || survey_id:, laplace;
log close; 


/* TABLE 2 - MODEL 2
Adding varying slopes for winners and "the same".
*/
log using "${TABLES}tab2-multilevel_model2.log", replace;
xtmelogit eu_support fpro1 fpro2 male edu2 edu3 age || survey_id: fpro1 fpro2, cov(unstructure) laplace;
log close;


/* TABLE 2 - MODEL 3
Adding country-level variables transition.indicator, GDP 1989, and unemployment rate.
*/
log using "${TABLES}tab2-multilevel_model3.log", replace;
xtmelogit eu_support fpro1 fpro2 male edu2 edu3 age transition_indicator9 gdp89 unemployment_rate || survey_id: fpro1 fpro2, cov(unstructure) laplace;
log close;


/* TABLE 2 - MODEL 4
Adding interaction effects between winner/"the same" and "likely".
*/
log using "${TABLES}tab2-multilevel_model4.log", replace;
xtmelogit eu_support fpro1 fpro2 fpro1Xlikely fpro2Xlikely male edu2 edu3 age transition_indicator9 gdp89 unemployment_rate likely || survey_id: fpro1 fpro2, cov(unstructure) laplace;
log close;

 
/* TABLE 2 - MODEL 5
Adding interaction effect between winner/"the same" and EMA (economically most advanced).
*/
log using "${TABLES}tab2-multilevel_model5.log", replace;
xtmelogit eu_support fpro1 fpro2 fpro1Xlikely fpro2Xlikely fpro1Xema fpro2Xema male edu2 edu3 age transition_indicator9 gdp89 unemployment_rate likely ema || survey_id: fpro1 fpro2, cov(unstructure) laplace;
log close;


/* FIGURE 6
Predicted probabilities of supporting EU membership _given_ that a respondent either opposes or supports membership. All other variables are held at their mean or modal values.
*/
* Coefficients;
foreach name in fpro1 fpro2 fpro1Xlikely fpro2Xlikely fpro1Xema fpro2Xema male edu2 edu3 age transition_indicator9 gdp89 unemployment_rate likely ema {;
	gen B`name' = _b[`name'];
	};

gen Bcons = _b[_cons];

predict Branef*, reffects;
rename Branef1 Branef_fpro1;
rename Branef2 Branef_fpro2;
rename Branef3 Branef_cons;

foreach var of varlist age transition_indicator9 gdp89 unemployment_rate {;
	quietly sum `var';
	gen mean_`var' = r(mean);
	};
 
* Average random effects in each country;
bysort country: egen mean_Branef_fpro1 = mean(Branef_fpro1);
bysort country: egen mean_Branef_fpro2 = mean(Branef_fpro2);
bysort country: egen mean_Branef_cons  = mean(Branef_cons);
	
* Reduce to one row per survey;
bysort survey_id: gen tmp = _n;
keep if tmp == 1;
drop tmp;

gen winner_prob = .;
gen loser_prob  = .;

gen Xlikely = .;
replace Xlikely = 0 in 1;
replace Xlikely = 1 in 2;
replace Xlikely = 0 in 3;
replace Xlikely = 1 in 4;

gen Xema = .;
replace Xema = 0 in 1/2;
replace Xema = 1 in 3/4;

* CALCULATE PREDICTED PROBABILITIES FOR ALL 8 CASES;

* winner, likely=0, ema=0;
replace winner_prob = invlogit(Bfpro1 + Bmale + Bedu2 + Bage*mean_age + Btransition_indicator9*mean_transition_indicator9 + Bgdp89*mean_gdp89 + Bunemployment_rate*mean_unemployment_rate + Bcons) in 1;

* winner, likely=1, ema=0;
replace winner_prob = invlogit(Bfpro1 + Bfpro1Xlikely + Bmale + Bedu2 + Bage*mean_age + Btransition_indicator9*mean_transition_indicator9 + Bgdp89*mean_gdp89 + Bunemployment_rate*mean_unemployment_rate + Blikely + Bcons) in 2;

* winner, likely=0, ema=1;
replace winner_prob = invlogit(Bfpro1 + Bfpro1Xema + Bmale + Bedu2 + Bage*mean_age + Btransition_indicator9*mean_transition_indicator9 + Bgdp89*mean_gdp89 + Bunemployment_rate*mean_unemployment_rate + Bema + Bcons) in 3;

* winner, likely=1, ema=1;
replace winner_prob = invlogit(Bfpro1 + Bfpro1Xlikely + Bfpro1Xema + Bmale + Bedu2 + Bage*mean_age + Btransition_indicator9*mean_transition_indicator9 + Bgdp89*mean_gdp89 + Bunemployment_rate*mean_unemployment_rate + Blikely + Bema + Bcons) in 4;



* loser, likely=0, ema=0;
replace loser_prob = invlogit(Bmale + Bedu2 + Bage*mean_age + Btransition_indicator9*mean_transition_indicator9 + Bgdp89*mean_gdp89 + Bunemployment_rate*mean_unemployment_rate + Bcons) in 1;

* loser, likely=1, ema=0;
replace loser_prob = invlogit(Bmale + Bedu2 + Bage*mean_age + Btransition_indicator9*mean_transition_indicator9 + Bgdp89*mean_gdp89 + Bunemployment_rate*mean_unemployment_rate + Blikely + Bcons) in 2;

* loser, likely=0, ema=1;
replace loser_prob = invlogit(Bmale + Bedu2 + Bage*mean_age + Btransition_indicator9*mean_transition_indicator9 + Bgdp89*mean_gdp89 + Bunemployment_rate*mean_unemployment_rate + Bema + Bcons) in 3;

* loser, likely=1, ema=1;
replace loser_prob = invlogit(Bmale + Bedu2 + Bage*mean_age + Btransition_indicator9*mean_transition_indicator9 + Bgdp89*mean_gdp89 + Bunemployment_rate*mean_unemployment_rate + Blikely + Bema + Bcons) in 4;

gen diff = winner_prob - loser_prob;
l Xlikely Xema winner_prob loser_prob diff in 1/4;
sum winner_prob loser_prob in 1/4;


* BAR GRAPH;
gen Xcomb = _n in 1/4;
graph bar winner_prob loser_prob, 
	over(Xcomb, 
		relabel( 
			1 `" "unlikely to join" "and economically" "not advanced" "'
 			2 `" "likely to join" "and economically" "not advanced" "'
 			3 `" "unlikely to join" "and economically" "advanced" "'
 			4 `" "likely to join" "and economically" "advanced" "'
 			)) 
	legend(label(1 "winner") label(2 "loser"))
 	bar(1,color(gs3)) bar(2,color(gs10))
 	title(Probability of supporting EU membership);
graph export "${GRAPHS}fig6-predicted_probabilities_multilevel_model5.${GRAPH_TYPE}", replace;


exit;



 

                         
                         
                         
