/* 
===========================================================================================
= Replication file for Alexander Herzog and Joshua A. Tucker, "The Dynamics of Dissent:   =
= The Winners-Losers Gap in Attitudes Towards EU Membership in Post-Communist Countries," =
= European Political Science Review, 2010, forthcoming.                                   =
===========================================================================================

NOTE: This file replicates Table 1 and Figures 4 and 5 in the paper.

DATE: March 20, 2010

DATA SOURCE: The data set was built from three sources:
 1) the Central and Eastern Eurobarometer (CEEB) individual-level surveys from 1991, 1992, 1995 and 1996,
 2) the Candidate Countries Eurobarometer (CCEB) individual-level surveys from 2001, 2002 and 2003,
 3) macro-economic country-level data collected and kindly shared with us by Grigor Pop-Eleches.
 
See the paper for more details about the data and coding decisions.
*/

clear                                                               
version 10.0                                                        
set more off
capture log close
set mem 128m
set scheme s1mono
#delimit;

* =============================
* = FILE PATHS AND GRAPH TYPE =
* =============================;
global DATA = "~/replication_files/data/";
global GRAPHS = "~/replication_files/figures/";
global TABLES = "~/replication_files/tables/";
global GRAPH_TYPE = "eps";


* Load dataset;
use "${DATA}individual_level_data.dta";

* recode age as mean-centered;
sum age;
gen age_original = age;
replace age = age - r(mean);
label var age "Age (mean centered and recorded to [0,1] interval)";


/* TABLE 1
Multinomial logit model of EU support on winner/loser status and control variables. All countries (N=10) and years (N=7) are pooled together.
*/
log using "${TABLES}tab1-multinomial_logit_model.log", replace;
mlogit eu_support fpro1 fpro2 male edu2 edu3 age, base(2);
log close;


* ===================================================
* = SEPARATE MODELS FOR YEARS WITH POOLED COUNTRIES =
* ===================================================;
* NOTE: The below code estimates multinomial logit models for each year with countries
* in each year pooled together. For each model, pedicted probabilities for a typical 
* respondent are calculated and stored in a new variable. At the end of this do-file, the 
* data set is reduced to these predicted probabilites, which then are plotted in order to
* produce Figure 4 in the paper. 

* coefficients;
gen coef1_pooledyears = .;
gen coef2_pooledyears = .;

* c.i. upper and lower bound;
gen coef1_pooledyears_ub = .;	
gen coef1_pooledyears_lb = .;	

* simulated probability;
gen coef1_pooledyears_pred1 = .;	
gen coef1_pooledyears_pred2 = .;	

* set values of independent variables for which predicted values are computed;
global fpro1_1 	= "fpro1 1";
global fpro1_0 	= "fpro1 0";
global fpro2 	= "fpro2 0";
global male 	= "male 0";
global edu2 	= "edu2 1";
global edu3 	= "edu3 0";
global age	 	= "age mean";

foreach year of numlist 1991 1992 1995 1996 2001 2002 2003 {;
	di "`year'";
	estsimp mlogit eu_support fpro1 fpro2 male edu2 edu3 age if year == `year', base(2) genname(tmp);

	setx $fpro1_1 $fpro2 $male $edu2 $edu3 $age;
		simqi, prval(1) genpr(pred1);
		sum pred1;
	replace coef1_pooledyears_pred1 = r(mean) if year == `year';

	setx $fpro1_0 $fpro2 $male $edu2 $edu3 $age;
		simqi, prval(1) genpr(pred2);
		sum pred2;
		local mean = r(mean);
	replace coef1_pooledyears_pred2 = r(mean) if year == `year';

	replace coef1_pooledyears = _b[fpro1] if year == `year';
	replace coef2_pooledyears = _b[fpro2] if year == `year';

	replace coef1_pooledyears_ub = _b[fpro1] + 1.96 * _se[fpro1] if year == `year';
	replace coef1_pooledyears_lb = _b[fpro1] - 1.96 * _se[fpro1] if year == `year';
	drop pred1 pred2 tmp*;
 	};

	
* =====================================================
* = SEPARATE MODELS FOR EACH COUNTRY YEAR OBSERVATION =
* =====================================================;
* NOTE: The below code estimates multinomial logit models for each country-year observation.
* For each model, pedicted probabilities for a typical respondent are calculated and stored 
* in a new variable. At the end of this do-file, the data set is reduced to these predicted 
* probabilites, which then are plotted in order to produce Figure 5 in the paper. 

* coefficients;
gen coef1_unpooled = .;	
gen coef2_unpooled = .;	

* c.i. upper and lower bound;
gen coef1_unpooled_ub = .;	
gen coef1_unpooled_lb = .;	

* simulated probability;
gen coef1_unpooled_pred1 = .;	
gen coef1_unpooled_pred2 = .;	

* set values of independent variables for which predicted values are computed;
global fpro1_1 	= "fpro1 1";
global fpro1_0 	= "fpro1 0";
global fpro2 	= "fpro2 0";
global male 	= "male 1";
global edu2 	= "edu2 1";
global edu3 	= "edu3 0";
global age	 	= "age mean";

	
foreach country of numlist 3/7 9 {;
	foreach year of numlist 1991 1992 1995 1996 2001 2002 2003 {;
		di "`country'";
		di "`year'";
 		estsimp mlogit eu_support fpro1 fpro2 male edu2 edu3 age if country == `country' & year == `year', base(2) genname(tmp);
		
		setx $fpro1_1 $fpro2 $male $edu2 $edu3 $age;
			simqi, prval(1) genpr(pred1);
			sum pred1;
		replace coef1_unpooled_pred1 = r(mean) if country == `country' & year == `year';
		
		setx $fpro1_0 $fpro2 $male $edu2 $edu3 $age;
			simqi, prval(1) genpr(pred2);
			sum pred2;
			local mean = r(mean);
		replace coef1_unpooled_pred2 = r(mean) if country == `country' & year == `year';
 		
		replace coef1_unpooled = _b[fpro1] if country == `country' & year == `year';
		replace coef2_unpooled = _b[fpro2] if country == `country' & year == `year';
		
		replace coef1_unpooled_ub = _b[fpro1] + 1.96 * _se[fpro1] if country == `country' & year == `year';
		replace coef1_unpooled_lb = _b[fpro1] - 1.96 * _se[fpro1] if country == `country' & year == `year';
		drop pred1 pred2 tmp*;
	};
};

	

* separate for Czech Republic and Slovenia. No data in Slovenia for 1991, in CZR in 1991, 100% of winners supported EU membership of their country. Hence it is not possible to reliably estimate the winner coefficent;
foreach country of numlist 2 10 {;
	foreach year of numlist 1992 1995 1996 2001 2002 2003 {;
		di "`country'";
		di "`year'";
 		estsimp mlogit eu_support fpro1 fpro2 male edu2 edu3 age if country == `country' & year == `year', base(2) genname(tmp);
		
		setx $fpro1_1 $fpro2 $male $edu2 $edu3 $age;
			simqi, prval(1) genpr(pred1);
			sum pred1;
		replace coef1_unpooled_pred1 = r(mean) if country == `country' & year == `year';
		
		setx $fpro1_0 $fpro2 $male $edu2 $edu3 $age;
			simqi, prval(1) genpr(pred2);
			sum pred2;
			local mean = r(mean);
		replace coef1_unpooled_pred2 = r(mean) if country == `country' & year == `year';
 		
		replace coef1_unpooled = _b[fpro1] if country == `country' & year == `year';
		replace coef2_unpooled = _b[fpro2] if country == `country' & year == `year';
		
		replace coef1_unpooled_ub = _b[fpro1] + 1.96 * _se[fpro1] if country == `country' & year == `year';
		replace coef1_unpooled_lb = _b[fpro1] - 1.96 * _se[fpro1] if country == `country' & year == `year';
		drop pred1 pred2 tmp*;		
	};
};


* separate for Bulgaria and Romania because no data for 2003;
foreach country of numlist 1 8 {;
	foreach year of numlist 1991 1992 1995 1996 2001 2002 {;
		di "`country'";
		di "`year'";
 		estsimp mlogit eu_support fpro1 fpro2 male edu2 edu3 age if country == `country' & year == `year', base(2) genname(tmp);
		
		setx $fpro1_1 $fpro2 $male $edu2 $edu3 $age;
			simqi, prval(1) genpr(pred1);
			sum pred1;
		replace coef1_unpooled_pred1 = r(mean) if country == `country' & year == `year';
		
		setx $fpro1_0 $fpro2 $male $edu2 $edu3 $age;
			simqi, prval(1) genpr(pred2);
			sum pred2;
			local mean = r(mean);
		replace coef1_unpooled_pred2 = r(mean) if country == `country' & year == `year';
 		
		replace coef1_unpooled = _b[fpro1] if country == `country' & year == `year';
		replace coef2_unpooled = _b[fpro2] if country == `country' & year == `year';
		
		replace coef1_unpooled_ub = _b[fpro1] + 1.96 * _se[fpro1] if country == `country' & year == `year';
		replace coef1_unpooled_lb = _b[fpro1] - 1.96 * _se[fpro1] if country == `country' & year == `year';
		drop pred1 pred2 tmp*;		
	};
};



* =======================================================
* = Reduce data to country-year level with coefficients =
* =======================================================;
keep country country_short year coef1* coef2*;
bysort country year: gen tmp = _n;
keep if tmp == 1;

* recode year variable to have no gaps; 
recode year 1991=1 1992=2 1995=3 1996=4 2001=5 2002=6 2003=7;

* drop country-year observations for which no coefficients were estimated (CZR 1991, Slovenia 1991, Bulgaria 2003, Romania 2003);
drop if country == 2 & year == 1;
drop if country == 10 & year == 1;
drop if country == 1 & year == 7;
drop if country == 8 & year == 7;

label def year 
	1 "91"
	2 "92"
	3 "95"
	4 "96"
	5 "01"
	6 "02"
	7 "03";
label val year year;	

* label variables for graphs;	
label var coef1_unpooled_pred1 "Winners";
label var coef1_unpooled_pred2 "Losers";

label var coef1_pooledyears_pred1 "Winners";
label var coef1_pooledyears_pred2 "Losers";


/* FIGURE 4
Predicted probabilities for winners and losers supporting EU membership. Estimates are based on seven multinomial logit models estimated on each year separately with countries pooled together. All other variables are held at their modal or mean values, representing a 44 year old female respondent with secondary education.
*/
bysort year: gen year_id = _n;

twoway line coef1_pooledyears_pred1 coef1_pooledyears_pred2 year if year_id == 1,
	ylabel(0(0.2)1)
	c(l l) lpattern(solid dash) 
	xlabel(1 "1991" 2 "1992" 3 "1995" 4 "1996" 5 "2001" 6 "2002" 7 "2003", angle(0))
	xtitle("")
	;

graph export "${GRAPHS}fig4-predicted_probabilities_mlogit_models_pooled_by_years.${GRAPH_TYPE}", replace;


/* FIGURE 5
Predicted probabilities for winners and losers supporting EU membership. Estimates are based on 66 multinomial logit models estimated on each country-year observation separately. There are no estimates for the Czech Republic in 1991 because all winners supported the EU. The question about EU support was not asked in Slovenia in 1991. In 2003, the survey question regarding EU support referred to actual vote decision in the referendum, and consequently was not asked in Bulgaria and Romania where referenda were not held. All other variables are held at their modal or mean values, representing a 44 year old female respondent with secondary education.
*/
* plot of predicted values for winner and loser, over time and for each country separatly;
scatter coef1_unpooled_pred1 coef1_unpooled_pred2 year, 
	c(l l) lpattern(solid dash) 
	by(country,
	 	ixaxes
		iscale(*.8)
		note("")
		)
		ytitle("")
		xtitle("")
		ylabel(0(.2)1)
		xlabel(1 "1991" 2" 1992" 3 "1995" 4 "1996" 5 "2001" 6 "2002" 7 "2003", angle(25))
		;
graph export "${GRAPHS}fig5-predicted_probabilities_mlogit_models_completely_unpooled.${GRAPH_TYPE}", replace;



exit;




